# shine.scene

Probabilistic scene builder for NumPyro models.

Translates YAML configuration into a differentiable forward model that renders
galaxies with JAX-GalSim and evaluates the likelihood against observed data.

::: shine.scene
